//
//  AWTableViewController.h
//  AWTableViewController
//
//  Created by Ikuo Kudo on 12/07/06.
//  Copyright (c) 2012年   All rights reserved.
//


//   AWTableScrollView            　　<- AWTableView 表全体
//     +AWTableCellContainer  　                  ステージ
//          +AWTableCell　　　　　                      セル


#import <UIKit/UIKit.h>
#import "AWTableCell.h"



@interface AWTableIndexPath : NSObject

@property ( nonatomic, assign ) int stage;
@property ( nonatomic, assign ) int column;

+ ( AWTableIndexPath* ) makeWithStage: ( int ) aStage column: ( int ) aColumn;
@end

// -------------------------------------------------------------------------------

@class AWTableViewController;
@class AWTableController;
@class AWTableTopView;
@class AWTableScrollView;

@protocol AWTableViewControllerDelegate <NSObject>

- ( CGSize ) sizeForTableCellInTableView: ( AWTableViewController* ) tableView;                   // セルの大きさ
- ( CGSize ) sizeForTableStageInTableView: ( AWTableViewController* ) tableView;                  // ステージの大きさ
- ( int ) numberOfCellsAtTableStageInTableView: ( AWTableViewController* ) tableView;             // ステージ中のセルの数の最大値
- ( int ) numberOfVisibleStages: ( AWTableViewController* ) tableView;                   // ステージの最小値
- ( void ) tableView: ( AWTableViewController* ) tableView didScrollToPage : ( int ) stageIndex;  
- ( void ) tableView: ( AWTableViewController *) tableView didSelectRowAtIndexPath: ( AWTableIndexPath *) indexPath;  // セルが選択されたとき
                                            

@optional
- ( CGFloat ) heightForHeaderInTableView: ( AWTableViewController* ) tableView;                   // ヘッダーの高さ
- ( CGFloat ) heightForFooterInTableView:( AWTableViewController* ) tableView;                    // フッターの高さ
- ( UIView* ) viewForHeaderInTableView: ( AWTableViewController* )  tableView;                    // ヘッダービュー
- ( UIView* ) viewForFooterInTableView: ( AWTableViewController* ) tableView;                     // フッタービュー
@end



@interface AWTableViewController : UIViewController

@property ( nonatomic, assign ) id <AWTableViewControllerDelegate> delegate;
@property ( nonatomic, strong ) AWTableScrollView* tableScrollView;
@property ( nonatomic, strong ) NSMutableArray* tableStages;            
@property ( nonatomic, strong ) AWTableController* tableController;

@property ( nonatomic, assign ) int numberOfVisibleStage;
@property ( nonatomic, assign ) int cellCountPerStage;
@property ( nonatomic, assign ) CGSize stageSize;
@property ( nonatomic, assign ) CGFloat stageTopMargin;
@property ( nonatomic, assign ) CGFloat stageLeftMargin;
@property ( nonatomic, strong ) UIView* headerView;
@property ( nonatomic, strong ) UIView* footerView;

- ( void ) addStage;
- ( void ) reloadData;

@end
