//
//  AWTableViewController.m
//  AWTableViewController
//
//  Created by Ikuo Kudo on 12/07/06.
//  Copyright (c) 2012年   All rights reserved.
//

#import "AWTableViewController.h"
#import "AWTableScrollView.h"
#import "AWTableTopView.h"
#import "AWTableCellContainer.h"
#import "AWTableController.h"
#import "Constants.h"


@implementation AWTableIndexPath
@synthesize stage, column;

+ ( AWTableIndexPath* ) makeWithStage: ( int ) aStage column: ( int ) aColumn
{
    AWTableIndexPath* index = [ [ AWTableIndexPath alloc ] init ];
    index.stage = aStage;
    index.column = aColumn;
    
    return index;
}

@end


// -------------------------------------------------------------------------------

@interface AWTableViewController ()
{
    CGPoint topOfStage;
    CGSize cellSize;
    

    int stageCount;
}

- ( void ) setDefault;
- ( void ) initViews;
- ( void ) setupWithFrame: ( CGRect ) frame;
@end

@implementation AWTableViewController
@synthesize delegate;
@synthesize tableController;
@synthesize tableStages;
@synthesize tableScrollView;
@synthesize numberOfVisibleStage, cellCountPerStage;
@synthesize stageTopMargin, stageLeftMargin;
@synthesize  headerView, footerView;
@synthesize stageSize;

- ( id ) init
{
    DLog();
    
    self = [ super init ];
    if( self ) {
        
        [ self.view setBackgroundColor: [ UIColor yellowColor ] ];
        
        tableStages = [[ NSMutableArray alloc ] initWithCapacity: 0 ];
        tableController = [ [ AWTableController alloc ] initByController: self ];
        [ self setDefault ];
        [ self setupWithFrame: self.view.frame ];
    }
    
    return self;
}


- ( void ) reloadData
{
    if( [ delegate respondsToSelector: @selector( sizeForTableCellInTableView: )  ] ) {
        cellSize = [ delegate sizeForTableCellInTableView: self ];
    }
    
    if( [ delegate respondsToSelector: @selector(sizeForTableStageInTableView:) ] ) {
        stageSize = [ delegate sizeForTableStageInTableView: self ];
    }
    
    if( [ delegate respondsToSelector: @selector( numberOfCellsAtTableStageInTableView: ) ] ) {
        cellCountPerStage  = [ delegate numberOfCellsAtTableStageInTableView: self ];
    }    

    int nStageOld = numberOfVisibleStage;
    if( [ delegate respondsToSelector: @selector( numberOfVisibleStages: ) ] ) {
        
        numberOfVisibleStage  = [ delegate numberOfVisibleStages: self ];
        int delta = numberOfVisibleStage - nStageOld;
        if( delta > 0 ) {
            // ステージが増えるとき
            for( int i = 0; i < delta; i++ ) {
                [ self addStage ];
            }
        }
//        else if ( delta < 0 ) {
//            
//            // ステージが減るとき
//            for( int i = 0; i < delta; i++ ) {
//                [ self removeLastStage ];
//            }    
//        }
    }
    
    CGRect rect;
    rect.origin.y = headerView.frame.size.height + stageTopMargin;
    rect.origin.x = stageLeftMargin;
    rect.size.height = stageSize.height;
    topOfStage = CGPointMake( 0, rect.origin.y );
    
    for( int i = 0; i < numberOfVisibleStage + 1; i++ ) {
        AWTableCellContainer* stage = [[ AWTableCellContainer alloc ] initWithFrame: rect ];
        [ stage setFrame: rect ];
        rect.origin.y += stageSize.height + stageTopMargin;
    }
    
    
    tableController.rowMax = numberOfVisibleStage;
    tableController.columnMax = cellCountPerStage;
    tableController.beginStageIndex = 0;
    tableController.endStageIndex = numberOfVisibleStage - 1;
    [ tableController reloadDataWithStages: self.tableStages ];    
}


- ( void ) viewDidLoad
{
    DLog();
    
    [ super viewDidLoad ];
    
    }

- ( void ) viewDidAppear:(BOOL)animated
{
    DLog();
    [ super viewDidAppear: animated ];
    
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

- ( void ) setDefault
{
    if( [ Constants isPhone ] ) {
        cellSize = CGSizeMake( 60, 90 );
        stageSize = CGSizeMake( 100, 120 );
        cellCountPerStage = 4;
        numberOfVisibleStage = 5;
        stageTopMargin = 10;
        stageLeftMargin = 10;
    }
    else {
        cellSize = CGSizeMake( 60, 70 );
        stageSize = CGSizeMake( 100, 120 );
        cellCountPerStage = 4;
        numberOfVisibleStage = 5;
        stageTopMargin = 10;
        stageLeftMargin = 10;
    }
}

- ( void ) setupWithFrame: ( CGRect ) frame
{
    CGRect rect = frame;
    
    //スクロール画面
    tableScrollView = [ [ AWTableScrollView alloc ] initWithFrame: frame ];
    [ self.view addSubview: self.tableScrollView ];
    
    // テーブルヘッダービュー
    rect.size.height = 50;
    rect.origin.y = 0;
    headerView = [ [ AWTableTopView alloc ] initWithFrame: rect ];
    [ headerView setBackgroundColor: [ UIColor greenColor ] ];
    [ tableScrollView addSubview: headerView ];
    
    // ステージとはテーブルのRow(行）を意味する。
    rect.origin.y = headerView.frame.size.height + stageTopMargin;
    rect.origin.x += stageLeftMargin;
    rect.size.height = stageSize.height;
    topOfStage = CGPointMake( 0, rect.origin.y );
    for( int i = 0; i < numberOfVisibleStage + 5; i++ ) {
        AWTableCellContainer* stage = [[ AWTableCellContainer alloc ] initWithFrame: rect ];
        stage.row = i;
        [ tableStages addObject: stage ];
        [ self.tableScrollView addSubview: stage ];
        rect.origin.y += stageSize.height + stageTopMargin;
    }
    
    CGSize size = frame.size;
    size.height += 200;
    [ tableScrollView setContentSize: size ];
    [ self.view addSubview: tableScrollView ];
}

- ( void ) addStage
{
    AWTableCellContainer* s = [ tableStages objectAtIndex: [ tableStages count ] - 1 ];
    CGRect rect = s.frame;

    rect.origin.y += headerView.frame.size.height;
    AWTableCellContainer* stage = [[ AWTableCellContainer alloc ] initWithFrame: rect ];
    stage.row = [ tableStages count ] + 1;
    [ tableStages addObject: stage ];
    [ self.tableScrollView addSubview: stage ];    
}

- ( void ) removeLastStage
{
    int last = [ tableStages count ] - 1;
    AWTableCellContainer* stage = [ tableStages objectAtIndex: last ];
    [ stage removeFromSuperview ];
    [ tableController removeContainer: stage ];
    [ tableStages removeLastObject ];
}

- ( void ) viewWillAppear:(BOOL)animated
{
    DLog();
    
    [ super viewWillAppear: animated ];
}

@end
