//
//  ViewController.m
//  AWTableView
//
//  Created by Ikuo Kudo on 12/07/12.
//  Copyright (c)All rights reserved.
//

#import "ViewController.h"
#import "AWTableViewController.h"

@interface ViewController ()
{
    CGSize cellSize;
    CGSize stageSize;
}
@property ( strong, nonatomic ) NSMutableArray* images;

- ( void ) setup;

@end

@implementation ViewController
@synthesize tableViewController;
@synthesize images;


- ( void ) setup
{
    cellSize = CGSizeMake(  60, 80 );
    stageSize = CGSizeMake( 320, 140 );
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        [ self setup ];
        
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    tableViewController = [ [ AWTableViewController alloc ] init ];
    tableViewController.delegate = self;
    tableViewController.tableController.dataSource = self;
   
    
    [ self.view addSubview: tableViewController.view ];
    
    images = [ NSMutableArray arrayWithCapacity: 0 ];
    for(int i = 0; i < 20; i++ ) 
    {
        NSString* file = [ NSString stringWithFormat: @"%d.png", i+1 ];
        UIImage* image = [ UIImage imageNamed: file ];
        [ images addObject: image ];
    }
}

- ( void ) viewWillAppear:(BOOL)animated
{
    DLog();
    
    [ super viewWillAppear: animated ];    
    
     [ tableViewController reloadData ];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}


#pragma mark - AWTableViewControllerDelegate

// セルの大きさ
- ( CGSize ) sizeForTableCellInTableView: ( AWTableViewController* ) tableView                
{
    return cellSize;
}

// ステージの大きさ
- ( CGSize ) sizeForTableStageInTableView: ( AWTableViewController* ) tableView                  
{
    return stageSize;
}

// ステージ中のセルの数の最大値
- ( int ) numberOfCellsAtTableStageInTableView: ( AWTableViewController* ) tableView         
{
    return 4;
}

// 
- ( int ) numberOfVisibleStages: ( AWTableViewController* ) tableView                 
{
    return 4;
}

- ( void ) tableView: ( AWTableViewController* ) tableView didScrollToPage : ( int ) stageIndex
{
    
}

// セルが選択されたとき
- ( void ) tableView: ( AWTableViewController *) tableView didSelectRowAtIndexPath: ( AWTableIndexPath *) indexPath  
{
    
}

// ヘッダーの高さ
- ( CGFloat ) heightForHeaderInTableView: ( AWTableViewController* ) tableView                   
{
    return 10;
}

// フッターの高さ
- ( CGFloat ) heightForFooterInTableView:( AWTableViewController* ) tableView                   
{
    return 0;
}

// ヘッダービュー
- ( UIView* ) viewForHeaderInTableView: ( AWTableViewController* )  tableView                   
{
    return nil;
}

// フッタービュー
- ( UIView* ) viewForFooterInTableView: ( AWTableViewController* ) tableView                    
{
    return nil;
}

#pragma mark - AWTableControllerDelegate

// セルの合計数
- ( int ) numberOfCellsInTableView: ( AWTableController* ) controller                                           
{
    return [ images count ];
}



// セルを返す
- ( AWTableCell* ) controller:( AWTableController* ) controller cellForTableAtIndexPth: ( AWTableIndexPath* ) indexPath  
{
    NSString *CellIdentifier = @"cell";
    
    AWTableCell* cell = [ controller dequeueReusableCellWithIdentifier: CellIdentifier ];
	if( !cell ) {
		cell = [ [ AWTableCell alloc] initWithFrame: CGRectMake( 0, 0, cellSize.width, cellSize.height ) ];
     
        int nStage = indexPath.stage;
        int nColumn = indexPath.column;
        int index = nStage * 4 + nColumn;
        if( index < [ images count ] ) {
            cell.image = [ images objectAtIndex: index ];
            cell.title.text =  [ NSString stringWithFormat: @"No.%d", index + 1 ];
        }
        else {
            cell.image = nil;
            cell.title.text = @"none";
        }
 	}
	
	return cell;    
}


@end
