//
//  AWTableCellContainer.m
//  AWTableView
//
//  Created by Ikuo Kudo on 12/07/09.
//  Copyright (c) 2012年   All rights reserved.
//

#import "AWTableCellContainer.h"
#import "AWTableCell.h"

@interface AWTableCellContainer ()
- ( void ) reindexAllCells;
@end

@implementation AWTableCellContainer
@synthesize row, cells,  cellSpace, cellInsets;

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        self.cells = [ NSMutableArray arrayWithCapacity: 0 ];
        self.backgroundColor = [ UIColor blueColor ];
        
        cellInsets = UIEdgeInsetsMake(10, 10, 10, 20 );
    }
    return self;
}

- ( void ) reloadDataWithFrame: ( CGRect ) frame cellInsets: ( UIEdgeInsets ) insets
{
    [ self setFrame: frame ];
    self.cellInsets = insets;
    
    
}

- ( void ) reindexAllCells
{
    for( int i = 0; i < [ self.cells count ]; i++ ) {
        AWTableCell* cell = [ self.cells objectAtIndex: i ];
        if( cell ) cell.column = i;
    }
}

- ( void ) addCell: ( AWTableCell* ) cell
{
    if( !cell ) return;
    
    CGRect rect = cell.frame;
    int n = [ self.cells count ];
    rect.origin.x = cellInsets.left + n * ( cell.frame.size.width + cellInsets.right );
    rect.origin.y = cellInsets.top;
    [ cell setFrame: rect ];
    [ self.cells addObject: cell ];
    [ self addSubview: cell ];
    [ self reindexAllCells ];
}

- ( void ) insertCellAtIndex: ( int ) index cell : ( AWTableCell* ) cell
{
    if( !cell ) return;
    
    CGRect rect = cell.frame;
    rect.origin.x = cellInsets.left + index * ( rect.size.width + cellInsets.right );
    rect.origin.y = cellInsets.top;
    [ cell setFrame: rect ];
    [ self.cells insertObject: cell  atIndex: index ];
    [ self addSubview: cell ];
    
    for( int i = index + 1; i < [ self.cells count ]; i++ ) 
    {
        AWTableCell* aCell = [ self.cells objectAtIndex: i ];
        CGRect rect = aCell.frame;
        rect.origin.x += cellInsets.right + cellInsets.left + rect.size.width;
    }
    
    [ self reindexAllCells ];
}

- ( AWTableCell* ) removeCellAtIndex: ( int ) index
{
    if( index < 0 || index > [ self.cells count ] ) return nil;
    
    AWTableCell* cell = [ self.cells objectAtIndex: index ];
    [ cell removeFromSuperview ];
    if( index < [ self.cells count ] - 1 ) {
        for( int i = index + 1; i < [ self.cells count ]; i++ ) 
        {
            AWTableCell* aCell = [ self.cells objectAtIndex: i ];
            CGRect rect = aCell.frame;
            rect.origin.x -= cellInsets.right + cellInsets.left + rect.size.width;
        }
    }

    [ self reindexAllCells ];
    
    [ self.cells removeObjectAtIndex: index ];
    
    return cell;
}

- ( void ) removeAllCells
{
    for( int i = 0; i < [ self.cells count ]; i++ ) {
        AWTableCell* cell = [ self.cells objectAtIndex: i ];
        [ cell removeFromSuperview ];
    }
    [ self.cells removeAllObjects ];
}




@end
